Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
// Algorithms is the list of allowed compression algorithms in order of preference
Algorithms []Algorithm
// MinSize is the minimum response size to compress (in bytes)
MinSize int
// Level is the compression level (-1 = default, 0 = no compression, 1-9 for gzip)
Level int
}
Config holds compression configuration
func DefaultConfig ¶
func DefaultConfig() Config
DefaultConfig returns the default compression configuration
Click to show internal directories.
Click to hide internal directories.